import 'package:flutter/cupertino.dart';
import 'package:nui_animation/nui_animation.dart';

class NUIScaleAnimation extends StatefulWidget {
  NUIScaleAnimation({required this.child, this.duration, this.begin = 0.0, this.end = 100.0, this.endAnimationListener, Key? key}): super(key: key);
  final Widget child;
  final Duration? duration;
  final double begin;
  final double end;
  final EndAnimationListener? endAnimationListener;
  @override
  _NUIScaleAnimationState createState() => _NUIScaleAnimationState();
}

class _NUIScaleAnimationState extends State<NUIScaleAnimation> with SingleTickerProviderStateMixin {
  late Animation<double> animation;
  late AnimationController controller;

  @override
  void initState(){
    super.initState();
    controller = AnimationController(
        duration: widget.duration ?? Duration(milliseconds: 500),
        vsync: this
    );
    animation = Tween<double>(begin: widget.begin, end: widget.end).animate(controller)
      ..addListener(() {
        final ended = animation.value == widget.end;
        if(ended) {
          if(widget.endAnimationListener != null) widget.endAnimationListener!();
        }
        setState(() {

        });
      });
    controller.forward();
  }

  @override
  Widget build(BuildContext context) {
    return Transform.scale(
        scale: animation.value/widget.end,
        child: widget.child
    );
  }
}